destroy_image_resources

Function destroy_image_resources 

pub unsafe fn destroy_image_resources(
    device: &Device,
    image: Image,
    view: ImageView,
    memory: DeviceMemory,
)
Safety

  • image, view, and memory must be created via the same device.
  • None of the objects must be currently in use by the GPU (all command buffers referencing them must be finalized - usually guaranteed via device_wait_idle or a fence/semaphore before the call).
  • Each object must not be destroyed more than once.