pub unsafe fn destroy_image_resources(
device: &Device,
image: Image,
view: ImageView,
memory: DeviceMemory,
)Expand description
Safety
image,view, andmemorymust be created via the samedevice.- None of the objects must be currently in use by the GPU
(all command buffers referencing them must be finalized -
usually guaranteed via
device_wait_idleor a fence/semaphore before the call). - Each object must not be destroyed more than once.